---
title: Usage
description: Information about the usage of the ThemePark plugins
published: true
date: 2024-12-20T17:57:45.124Z
tags: 
editor: markdown
dateCreated: 2023-02-16T21:10:36.262Z
---

# ThemePark
Information about the ThemePark plugin.

## Commands and Permissions
| Command | Description | Permission |
|---|---|---|
| `/themepark help` | Display the help list. |  |
| `/themepark menu` | Open the attraction menu. |  |
| `/themepark item` | Get the attraction menu item. |  |
| `/themepark region list` | Get a list of all the regions. | themepark.admin |
| `/themepark region create <Region ID> <Name>` | Create a new region with ID and displayname. | themepark.admin |
| `/themepark region name <Region ID> <Name>` | Change the name of a region by ID. | themepark.admin |
| `/themepark region material <Region ID> <Material>` | Change the item of the region in the attraction menu by ID. | themepark.admin |
| `/themepark region remove <Region ID>` | Delete a region by ID. | themepark.admin |
| `/themepark attraction list` | Get a list of all the attractions. | themepark.admin |
| `/themepark attraction warp <Attraction ID>` | Warp to an attraction by ID. |  |
| `/themepark attraction create <Attraction ID> <Region ID> <Name>` | Create a new attraction with ID, region ID and displayname. | themepark.admin |
| `/themepark attraction name <Attraction ID> <Name>` |  Change the name of an attraction by ID. | themepark.admin |
| `/themepark attraction cover <Attraction ID> <Cover>` | Change the cover image of an attraction by ID.<br>**Only applicable if ThemeParkPanel is used!** | themepark.admin |
| `/themepark attraction status <Attraction ID> <Status>` | Change the status of an attraction by ID.<br>*Available statuses are listed below.* | themepark.admin |
| `/themepark attraction location <Attraction ID>` | Change the location of an attraction to your current location by ID. |  themepark.admin |
| `/themepark attraction remove <Attraction ID>` |  Delete an attraction by ID. |   themepark.admin |
| `/themepark status name <Status> <Name>` | Change the name of a status. |   themepark.admin |
| `/themepark status color <Status> <Color>` | Change the color of a status.<br>*For example: `&4`* |   themepark.admin |
| `/themepark status hex_color <Status> <Color>` | Change the HEX color of a status.<br>*For example: `#3498db`*<br>**Only applicable if ThemeParkPanel is used!** |   themepark.admin |
| `/themepark status material <Status> <Material>` | Change the material of a status in the attraction menu. |   themepark.admin |
| `/themepark status teleport <Status> <Teleport?>` | Set if players can teleport from the attraction menu at a specific status.<br>*Available: `true` / `false`* |   themepark.admin |
| `/themepark ridecount get <Attraction ID> <Player>` | Get the ridecount of a player by an attraction ID. | themepark.admin |
| `/themepark ridecount add <Attraction ID> <Selector> <Amount>` | Add an amount to the ridecount of a (set of) player(s). *Use the Minecraft selector to select players. For example: @a[region=myrideregion]* |  themepark.admin |
| `/themepark ridecount total_type <Type>` | Change for which interval ridecount values will be valid.<br>*Available: `DAILY`, `WEEKLY`, `MONTHLY`, `YEARLY`, `TOTAL` (Where TOTAL is always valid)* |  themepark.admin |

> **Available statuses:** `GLOBAL`, `CONSTRUCTION`, `OPEN`, `CLOSED`, `MAINTENANCE`, `MALFUNCTION`
{.is-info}

## Signs

### Status
ThemePark provides a status sign which shows the status of an attraction and can teleport players to the attraction at click.

```
[ThemePark]
<Attraction ID>
```

The first line can be changed in the `settings.yml`. Make sure to adapt at creation.

### Ridecount
ThemePark provides a [TrainCarts](https://www.spigotmc.org/resources/traincarts.39592/) sign for adding to the ridecount of an attraction.
```
[train]
ridecount
<Attraction ID>
<Amount>
```

# ThemeParkConnector
Information about the ThemeParkConnector plugin.

## Commands

- `/tpc reload` - Reload the plugin.
- `/tpc redeem <Voucher>` - Redeem a voucher for a show.
- `/tpc state <Attraction ID> <Button ID> <State ID` - Change the state of a button for an attraction at the online panel. Most of the time, you use this command in a commandblock.

## Permissions

- `themepark.admin` - All the other functions who are for admins!
- `themepark.control` - Needed to control attractions on the panel

## Signs

### Control sign (for online panel):

```
[ParkControl]
<Attraction ID>
```

### Ticket sign (for online panel):

```
[Scanner Tag]
<Show ID>
<X>:<Y>:<Z>(:<Yaw>:<Pitch>)
<Hour>:<Minute>( <Day>-<Month>-<Year>)
```

Options between ( ) are optional. The scanner tag can be found in `settings.yml`.

# ThemeParkPlus

## Commands

- `/themeparkplus opengate <World> <X> <Y> <Z> [ARG 1] [ARG 2]` - This command opens a gate.
If you fill in a number of players in ARG 1, it will close if that amount of players passed the gate. If you fill in a direction in ARG 1, it will only let the players through the gate if the walk in that direction.
If you fill in a direction in ARG 2, it will only let the players through the gate if the walk in that direction. But you also need to use ARG 1, with a amount of players for this.
- `/themeparkplus closegate <World> <X> <Y> <Z>` - This command closes a gate.
- `/themeparkplus lampon <World> <X> <Y> <Z> [Seconds on]` - This command will turn on a redstone lamp. If you fill in an amount of seconds, it will go off after that amount of seconds.
- `/themeparkplus lampoff <World> <X> <Y> <Z>` - This command will turn off a redstone lamp.
- `/themeparkplus lampson <World> <X1> <Y1> <Z1> <X2> <Y2> <Z2> [Seconds on]` - This command will turn on all the redstone lamps in the region. If you fill in an amount of seconds, they will go off after that amount of seconds.
- `/themeparkplus lampsoff <World> <X> <Y> <Z>` - This command will turn off all the redstone lamps in the region.

## Permissions

- `ThemeParkPlus.OpenGate` - The opengate command permission 
- `ThemeParkPlus.CloseGate` - The closegate command permission 
- `ThemeParkPlus.LampOn` - The lampoff command permission 
- `ThemeParkPlus.LampOff` - The lampoff command permission 
- `ThemeParkPlus.CreateFPSign` - The fastpass sign create permission

## Signs

### Fastpass Machine:

```
[ThemeParkPlus] 
Machine
<Ride ID>
<Cost>
```

### Fastpass Checker:

```
[ThemeParkPlus]
Scanner
<RideID>
<Teleport or gate location -> X:Y:Z>
```

### Waitingrow:

If you create your first waitingrow for an attraction, you have to make a selection of the row with the WorldEdit wand (left click for Pos1, right click for Pos2), and create an WorldGuard region with that selection.

```
[ThemeParkPlus] 
WaitingRow
<Ride ID>
[Region ID]
```

The Region ID is only needed if it's the first sign for that Ride.

### Malfunction GUI:

```
[ThemeParkPlus]
Malfunction
<RideID>
```